import { csv, select,legendColor } from 'd3';
import { scatterPlot } from './scatterPlot';


const csvUrl = 'https://gist.githubusercontent.com/SatyaVineeth/0b3f4302684d3c3a196ad25b47ded7c1/raw/ad7e0c4933866a984bf48df82345922f2d98b44d/Wine%2520Dataset';

const parseRow = (d) => {
  d.fixed_acidity = +d.fixed_acidity;
  d.volatile_acidity = +d.volatile_acidity;
  d.chlorides = +d.chlorides;
  d.pH = +d.pH;
  return d;
};

const width = window.innerWidth;
const height = window.innerHeight;
const svg = select('body')
  .append('svg')
  .attr('width', width)
  .attr('height', height);

const xValue = (d) => d.chlorides;
const yValue = (d) => d.pH;
const rxValue = (d) => d.fixed_acidity;
const ryValue = (d) => d.volatile_acidity;
const type = (d) => d.type;
const colorValue = d => d.type;
const colorLabel = 'Types of Wine';

const main = async () => {
  const data = await csv(csvUrl, parseRow);
  const x = xValue((d) => d.pH);
  const y = yValue((d) => d.fixed_acidity);
  const marker = (d) => {
        	switch(d){
            case 'red':
              return 'red';
            case 'white':
              return 'yellow';
          }
        }
  
  const marks = data.map((d) => ({
          x: xValue((d) => d.pH),
          y: yValue((d) => d.fixed_acidity),
          species: type(d),
          color: marker(type(d)),
        	rx: rxValue(d),
          ry: ryValue(d),
                      
        }));
  
  
  const plot = scatterPlot()
    .width(width)
    .height(height)
    .data(await csv(csvUrl, parseRow))
    .xValue((d) => d.pH)
    .yValue((d) => d.fixed_acidity)
    .margin({
      top: 30,
      right: 50,
      bottom: 80,
      left: 95,

    })
    .radius(5);
  
  
 const g = svg.append('g')
          .attr('transform', `translate(${100},${100})`);

      const colorLegendG = g.append('g')
          .attr('transform', `translate(${100}, 150)`);


svg
          .selectAll('circle')
          .data(marks)
          .join('circle')
          .attr('cx', (d) => d.x)
          .attr('cy', (d) => d.y)
        	.attr('fill', (d) => d.color)
        	.attr('rx', (d) => (d.rx))
        	.attr('ry', (d) => (d.ry));
  
  const columns = [
    'pH',
    'volatile_acidity',
    'chlorides',
    'fixed_acidity',
  ];
  
  let i = 0;
  setInterval(() => {
    plot.xValue((d) => d[columns[i % columns.length]]);  /* Generates  'petal_width',
    'sepal_width',
    'petal_length',
    'sepal_length'*/
		svg.selectAll('text').remove();
    svg.call(plot);
    
      colorLegendG.append('text')
          .attr('class', 'legend-label')
          .attr('x', -70)
          .attr('y', -210)
          .style("font-style","italic")
          .style("stroke","black")
          .text(colorLabel);

   
svg.append("text").attr("x", 450).attr("y", 20).text("ICE-7 Reusable Scatterplot").attr("alignment-baseline","middle")

// Add labels in the legend
svg.append("text").attr("x", 150).attr("y", 70).text("Red").style("font-size", "20px").attr("alignment-baseline","middle")
svg.append("text").attr("x", 150).attr("y", 100).text("White").style("font-size", "20px").attr("alignment-baseline","middle")
    svg
        	.append("text")
        	.attr('transform', 'rotate(-90)')
        	.attr('x',0 - (height /2))
        	.attr("y",  height/12)
        	.style("text-anchor", "middle")
        	.style("font-style","italic")
        	.style("font-weight","bold")
        	.text("fixed_acidity"); 
    // Add points for legend
    svg.append("circle").attr("cx",130).attr("cy",70).attr("r", 6).style("fill", "red")
		svg.append("circle").attr("cx",130).attr("cy",100).attr("r", 6).style("fill", "yellow")
   // plot petal_width on x-axis
    if(i % columns.length==0) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("pH");
     // plot sepal_width on x-axis
    else if(i % columns.length==1) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("volatile_acidity");
     // plot petal_length on x-axis
    else if(i % columns.length==2) 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("chlorides");
     // plot sepal_length on x-axis
       else 
    svg
        	.append("text")
        	.attr("x", width / 2 )
      		.attr("y",  480 )
        	.style("text-anchor", "middle")
        	.style("font-style","Ariel")
        	.style("font-weight","bold")
      		.text("fixed_acidity");
    i++;
  }, 2000);// every 2 seconds change the visualization
};
main();



